@@ -51,13 +51,41 @@ print(cl)
 parallel::stopCluster(cl)
 
 
+message("- makeClusterPSOCK() - useXDR = TRUE/FALSE")
+
+for (xdr in c(TRUE, FALSE)) {
+  cl <- makeClusterPSOCK(1L, useXDR = xdr)
+  node <- cl[[1]]
+  stopifnot(
+    is.list(node),
+    inherits(node, if (xdr) "SOCKnode" else "SOCK0node"),
+    "session_info" %in% names(node)
+  )
+  si <- node[["session_info"]]
+  stopifnot(is.list(si))
+  parallel::stopCluster(cl)
+}
+
+
+message("- makeClusterPSOCK() - setup_strategy = TRUE/FALSE")
+
+for (setup_strategy in c("sequential", "parallel")) {
+  dt <- system.time({
+    cl <- makeClusterPSOCK(2L, setup_strategy = setup_strategy)
+  })
+  print(dt)
+  print(cl)
+  parallel::stopCluster(cl)
+}
+
+
 message("- makeClusterPSOCK() - with and w/out validation")
 
 cl <- makeClusterPSOCK(1L, validate = TRUE) ## default
 node <- cl[[1]]
 stopifnot(
   is.list(node),
-  inherits(node, "SOCKnode"),
+  inherits(node, if (useXDR) "SOCKnode" else "SOCK0node"),
   "session_info" %in% names(node)
 )
 si <- node[["session_info"]]
@@ -68,7 +96,7 @@ cl <- makeClusterPSOCK(1L, validate = FALSE)
 node <- cl[[1]]
 stopifnot(
   is.list(node),
-  inherits(node, "SOCKnode"),
+  inherits(node, if (useXDR) "SOCKnode" else "SOCK0node"),
   ! "session_info" %in% names(node)
 )
 parallel::stopCluster(cl)
